@@ -1,4 +1,7 @@
 package Net::DNS::SPF::Expander;
+{
+  $Net::DNS::SPF::Expander::VERSION = '0.011';
+}
 
 use Moose;
 use IO::All -utf8;
@@ -1043,10 +1046,11 @@ Amiri Barksdale E<lt>amiri@campusexplorer.comE<gt>
 =head2 CONTRIBUTORS
 
 Neil Bowers E<lt>neil@bowers.comE<gt>
+Chris Weyl E<lt>cweyl@campusexplorer.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2013 the Net::DNS::SPF::Expander L</AUTHOR> listed above.
+Copyright (c) 2013 Campus Explorer, Inc.
 
 =head1 LICENSE
 
